from ..entity_table.dept import Dept as Dept, DeptCreate as DeptCreate, DeptResponse as DeptResponse, DeptUpdate as DeptUpdate
from _typeshed import Incomplete
from shudaodao_core import AsyncSession as AsyncSession, QueryRequest as QueryRequest

Dept_Router: Incomplete

async def dept_query(*, query: QueryRequest, db: AsyncSession = ...): ...
async def dept_create(*, create_model: DeptCreate, db: AsyncSession = ...): ...
async def dept_read(*, primary_id: int, db: AsyncSession = ...): ...
async def dept_update(*, primary_id: int, model_update: DeptUpdate, db: AsyncSession = ...): ...
async def dept_delete(*, primary_id: int, db: AsyncSession = ...): ...
