from ..auth.auth_router import AuthRouter as AuthRouter
from ..entity.auth_user import AuthLogin as AuthLogin, AuthPassword as AuthPassword, AuthRegister as AuthRegister, AuthUser as AuthUser
from ..services.auth_service import AuthService as AuthService
from ..services.data_service import DataService as DataService
from ..utils.response_utils import ResponseUtil as ResponseUtil
from _typeshed import Incomplete
from fastapi import Request as Request
from fastapi.security import OAuth2PasswordRequestForm as OAuth2PasswordRequestForm
from sqlmodel.ext.asyncio.session import AsyncSession as AsyncSession

Auth_Controller: Incomplete

async def auth_register(register_model: AuthRegister, db: AsyncSession = ...): ...
async def auth_login(login_model: AuthLogin, db: AsyncSession = ...): ...
async def auth_token(request: Request, form_data: OAuth2PasswordRequestForm = ..., db: AsyncSession = ...): ...
async def auth_logout(): ...
async def auth_refresh(): ...
async def auth_me(current_user: AuthUser = ...): ...
async def auth_me_password(password_model: AuthPassword, db: AsyncSession = ..., current_user: AuthUser = ...): ...
