from .meta_column import MetaColumn as MetaColumn
from dataclasses import dataclass
from sqlalchemy import inspect as inspect

@dataclass
class MetaTable:
    inspector = ...
    schema_name = ...
    router_path = ...
    table_or_view_name = ...
    file_name = ...
    class_name = ...
    columns: list[MetaColumn] = ...
    comment: str = ...
    generated_date: str = ...
    entity_imports: list[str] = ...
    table_args: str = ...
    def __init__(self, *, inspector: inspect, table_or_view_name, schema_name, output_entity_schema, router_path) -> None: ...
    def get_columns(self) -> list[MetaColumn]: ...
    @staticmethod
    def get_sa_type(column_type, is_primary: bool) -> str: ...
    def get_comment(self): ...
    def get_import_field(self) -> str: ...
