from ..entity_table.user import User as User, UserCreate as UserCreate, UserResponse as UserResponse, UserUpdate as UserUpdate
from _typeshed import Incomplete
from shudaodao_core import AsyncSession as AsyncSession, QueryRequest as QueryRequest

User_Router: Incomplete

async def user_create(*, create_model: UserCreate, db: AsyncSession = ...): ...
async def user_read(*, primary_id: int, db: AsyncSession = ...): ...
async def user_update(*, primary_id: int, update_model: UserUpdate, db: AsyncSession = ...): ...
async def user_delete(*, primary_id: int, db: AsyncSession = ...): ...
async def user_query(*, query: QueryRequest, db: AsyncSession = ...): ...
