from ..config.app_config import AppConfig as AppConfig
from _typeshed import Incomplete
from enum import Enum

class LoggingLevel(Enum):
    DEBUG: int
    INFO: int
    WARNING: int
    ERROR: int

class _Logger:
    line_length: int
    logger: Incomplete
    def __init__(self) -> None: ...
    def info(self, message: object, *args, **kwargs) -> None: ...
    def info_line(self) -> None: ...
    def debug(self, message: object, *args, **kwargs) -> None: ...
    def debug_line(self) -> None: ...
    def warning(self, message: object, *args, **kwargs) -> None: ...
    def error(self, message: object, *args, **kwargs) -> None: ...

logging: Incomplete
